EXPORTS
	??1CAtsLogger@@UAE@XZ @ 1 NONAME ; CAtsLogger::~CAtsLogger(void)
	?BeginTestCaseL@CAtsLogger@@QAEXABVTDesC16@@000@Z @ 2 NONAME ; void CAtsLogger::BeginTestCaseL(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &)
	?BeginTestCaseL@CAtsLogger@@QAEXABVTDesC16@@H00@Z @ 3 NONAME ; void CAtsLogger::BeginTestCaseL(class TDesC16 const &, int, class TDesC16 const &, class TDesC16 const &)
	?BeginTestCaseReportL@CAtsLogger@@QAEXABVTDesC16@@0ABVTTime@@00@Z @ 4 NONAME ; void CAtsLogger::BeginTestCaseReportL(class TDesC16 const &, class TDesC16 const &, class TTime const &, class TDesC16 const &, class TDesC16 const &)
	?BeginTestCaseReportL@CAtsLogger@@QAEXABVTDesC16@@HABVTTime@@00@Z @ 5 NONAME ; void CAtsLogger::BeginTestCaseReportL(class TDesC16 const &, int, class TTime const &, class TDesC16 const &, class TDesC16 const &)
	?BeginTestReportL@CAtsLogger@@QAEXXZ @ 6 NONAME ; void CAtsLogger::BeginTestReportL(void)
	?BeginTestSetL@CAtsLogger@@QAEXABVTDesC16@@000@Z @ 7 NONAME ; void CAtsLogger::BeginTestSetL(class TDesC16 const &, class TDesC16 const &, class TDesC16 const &, class TDesC16 const &)
	?CloseL@CAtsLogger@@QAEXXZ @ 8 NONAME ; void CAtsLogger::CloseL(void)
	?CommentL@CAtsLogger@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 9 NONAME ; void CAtsLogger::CommentL(class TRefByValue<class TDesC16 const >, ...)
	?CommentL@CAtsLogger@@QAEXABVTDesC16@@@Z @ 10 NONAME ; void CAtsLogger::CommentL(class TDesC16 const &)
	?ContinueAfterRebootL@CAtsLogger@@QAEXXZ @ 11 NONAME ; void CAtsLogger::ContinueAfterRebootL(void)
	?DebugL@CAtsLogger@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 12 NONAME ; void CAtsLogger::DebugL(class TRefByValue<class TDesC16 const >, ...)
	?DebugL@CAtsLogger@@QAEXABVTDesC16@@@Z @ 13 NONAME ; void CAtsLogger::DebugL(class TDesC16 const &)
	?DebugOutput@CAtsLogger@@QAEXABVTDesC16@@@Z @ 14 NONAME ; void CAtsLogger::DebugOutput(class TDesC16 const &)
	?EndTestCaseL@CAtsLogger@@QAEXXZ @ 15 NONAME ; void CAtsLogger::EndTestCaseL(void)
	?EndTestReportL@CAtsLogger@@QAEXXZ @ 16 NONAME ; void CAtsLogger::EndTestReportL(void)
	?EndTestSetL@CAtsLogger@@QAEXXZ @ 17 NONAME ; void CAtsLogger::EndTestSetL(void)
	?ErrorL@CAtsLogger@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 18 NONAME ; void CAtsLogger::ErrorL(class TRefByValue<class TDesC16 const >, ...)
	?ErrorL@CAtsLogger@@QAEXABVTDesC16@@@Z @ 19 NONAME ; void CAtsLogger::ErrorL(class TDesC16 const &)
	?ErrorMessage@CAtsLogger@@SA?BVTPtrC16@@ABH@Z @ 20 NONAME ; class TPtrC16 const CAtsLogger::ErrorMessage(int const &)
	?IsValid@CAtsLogger@@QAEHXZ @ 21 NONAME ; int CAtsLogger::IsValid(void)
	?NewL@CAtsLogger@@SAPAV1@ABVTDesC16@@H@Z @ 22 NONAME ; class CAtsLogger * CAtsLogger::NewL(class TDesC16 const &, int)
	?RawLogL@CAtsLogger@@QAAHV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 23 NONAME ; int CAtsLogger::RawLogL(class TRefByValue<class TDesC16 const >, ...)
	?RawLogL@CAtsLogger@@QAEHABVTDesC16@@@Z @ 24 NONAME ; int CAtsLogger::RawLogL(class TDesC16 const &)
	?SaveForRebootL@CAtsLogger@@QAEXXZ @ 25 NONAME ; void CAtsLogger::SaveForRebootL(void)
	?SetDebugOutput@CAtsLogger@@QAEXH@Z @ 26 NONAME ; void CAtsLogger::SetDebugOutput(int)
	?SetFullReporting@CAtsLogger@@QAEXH@Z @ 27 NONAME ; void CAtsLogger::SetFullReporting(int)
	?SetIndentation@CAtsLogger@@QAEXH@Z @ 28 NONAME ; void CAtsLogger::SetIndentation(int)
	?SetTestCaseResultL@CAtsLogger@@QAEXABVTDesC16@@@Z @ 29 NONAME ; void CAtsLogger::SetTestCaseResultL(class TDesC16 const &)
	?SetTestCaseResultL@CAtsLogger@@QAEXH@Z @ 30 NONAME ; void CAtsLogger::SetTestCaseResultL(int)
	?TestCaseFailed@CAtsLogger@@QAEXXZ @ 31 NONAME ; void CAtsLogger::TestCaseFailed(void)
	?TestCaseNa@CAtsLogger@@QAEXXZ @ 32 NONAME ; void CAtsLogger::TestCaseNa(void)
	?TestCasePassed@CAtsLogger@@QAEXXZ @ 33 NONAME ; void CAtsLogger::TestCasePassed(void)
	?TestCaseSkipped@CAtsLogger@@QAEXXZ @ 34 NONAME ; void CAtsLogger::TestCaseSkipped(void)
	?WarningL@CAtsLogger@@QAAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 35 NONAME ; void CAtsLogger::WarningL(class TRefByValue<class TDesC16 const >, ...)
	?WarningL@CAtsLogger@@QAEXABVTDesC16@@@Z @ 36 NONAME ; void CAtsLogger::WarningL(class TDesC16 const &)

